<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="75"/>
        <location filename="../mainwindow.cpp" line="434"/>
        <location filename="../mainwindow.cpp" line="483"/>
        <source>MX Cleanup</source>
        <translation>MX Úklid</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>Clean Folders</source>
        <translation>Složky k vyčištění</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <source>All (potentially dangerous)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="100"/>
        <source>Not accessed today (safer)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="178"/>
        <source>Display help </source>
        <translation>Zobrazit nápovědu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="188"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <source>About this application</source>
        <translation>O této aplikaci</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="220"/>
        <source>About...</source>
        <translation>O programu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="227"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="259"/>
        <source>Quit application</source>
        <translation>Ukončit aplikaci</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="262"/>
        <location filename="../mainwindow.cpp" line="549"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="269"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="307"/>
        <source>Apply</source>
        <translation>Použít</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="335"/>
        <source>Empty Trash</source>
        <translation>Vysypat Koš</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>Trash older than:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="348"/>
        <location filename="../mainwindow.ui" line="485"/>
        <location filename="../mainwindow.ui" line="691"/>
        <source>Don&apos;t empty</source>
        <translation>Nemazat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <location filename="../mainwindow.ui" line="723"/>
        <source> days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="377"/>
        <source>All users</source>
        <translation>Všichni uživatelé</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="396"/>
        <source>Selected user</source>
        <translation>Vybraný uživatel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="444"/>
        <source>Clear APT Cache</source>
        <translation>Vyčistit mezipaměť APT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="456"/>
        <source>Old files</source>
        <translation>Staré soubory</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="475"/>
        <source>All files</source>
        <translation>Všechny soubory</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="556"/>
        <source>At reboot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="606"/>
        <source>Free Disk Space for User</source>
        <translation>Uvolnit místo na disku uživatele</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="618"/>
        <location filename="../mainwindow.ui" line="631"/>
        <source>Select user to repair</source>
        <translation>Vybrat uživatele k opravě</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="634"/>
        <source>Select user:</source>
        <translation>Vyberte uživatele:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="765"/>
        <source>Kernel removal tool</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="771"/>
        <source>List and select kernels to remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="517"/>
        <source>Graphical Tool for Analyzing Disk Usage</source>
        <translation>Grafický nástroj pro analýzu využití disku</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>Run Disk Usage Analyzer</source>
        <translation>Spustit analýzu využití disku</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="537"/>
        <source>Schedule</source>
        <translation>Plán</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="549"/>
        <source>No automatic clean</source>
        <translation>Bez automatického čištění</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="563"/>
        <source>Daily</source>
        <translation>Denní</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="570"/>
        <source>Weekly</source>
        <translation>Týdenní</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="577"/>
        <source>Monthly</source>
        <translation>Měsíční</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="650"/>
        <source>Delete Logs</source>
        <translation>Smazat Log soubory</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="675"/>
        <source>All logs</source>
        <translation>Všechny logy</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="707"/>
        <source>Old logs</source>
        <translation>Staré logy</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="742"/>
        <source>Logs older than:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="427"/>
        <source>Done</source>
        <translation>Hotovo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="427"/>
        <source>Cleanup command done</source>
        <translation>Příkaz vyčištění byl dokončen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="428"/>
        <source>%1 MiB were freed</source>
        <translation>Bylo uvolněno %1 MiB</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>About</source>
        <translation>O aplikaci</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>Version: </source>
        <translation>Verze:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="437"/>
        <source>Quick and safe removal of old files</source>
        <translation>Rychlé a bezpečné odstranění starých souborů</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="439"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Vlastnická práva (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="440"/>
        <location filename="../mainwindow.cpp" line="451"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="441"/>
        <location filename="../mainwindow.cpp" line="459"/>
        <source>Changelog</source>
        <translation>Protokol změn</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="442"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="466"/>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="544"/>
        <source>Kernel currently in use: &lt;b&gt;%1&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="547"/>
        <source>Remove selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="552"/>
        <source>Similar kernels that can be removed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="553"/>
        <source>Other kernels that can be removed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="555"/>
        <source>&lt;b&gt;Nothing to remove.&lt;/b&gt; Cannot remove kernel in use.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>You must run this program as root.</source>
        <translation type="vanished">Tuto aplikaci musíte spustit jako root.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>Quick safe removal of old files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
